==> VMFA-232_100.zip: description.lua <==
livery = {

	{"f18c1", 0 ,"F18C_1_DIFF",false};
	{"f18c1", 1 ,"F18C_1_NM",false};
	{"f18c1", ROUGHNESS_METALLIC ,"F18C_1_DIFF_Roughmet",false};

	
	{"f18c2", 0 ,"F18C_2_DIFF",false};
	{"f18c2", 1 ,"F18C_2_NM",false};
	{"f18c2", ROUGHNESS_METALLIC ,"Hornet_2_RoughMet",false};

	
	{"FPU_8A", 0 ,"FPU_8A",false};
	{"FPU_8A", ROUGHNESS_METALLIC ,"FPU_8A_Diff_RoughMet",false};

	
	{"pilot_F18_patch", 0 ,"Pilot_F18_Patch",false};
	{"pilot_F18_patch", 1 ,"pilot_f18_helmet_nm",false};
	{"pilot_F18_patch", ROUGHNESS_METALLIC ,"Pilot_F18_Patch_RoughMet",false};
	{"pilot_F18_helmet_hmd", 0, "pilot_f18_helmet_hmd",false};
	{"pilot_F18_helmet_hmd", 1, "pilot_f18_helmet_hmd_nm",false};
	{"pilot_F18_helmet_hmd", ROUGHNESS_METALLIC, "pilot_f18_helmet_hmd_roughmet",false};
	{"pilot_F18_helmet", 0, "pilot_f18_helmet",false};
	{"pilot_F18_helmet", 1, "pilot_f18_helmet_nm",false};
	{"pilot_F18_helmet", ROUGHNESS_METALLIC, "pilot_f18_helmet_roughmet",false};
	
	{"Pilot_F18_FP_SuitTop",	DIFFUSE			,	"pilot_f18_fp_suittop", false};
	{"Pilot_F18_FP_Details",	DIFFUSE			,	"pilot_f18_fp_details", false};
	{"Pilot_F18_Body",	DIFFUSE			,	"pilot_f18", false};
	{"pilot_F18_visor_glass", 0, "pilot_f18_visor", false};

	
	{"f18c_wheel_101", 0, "f18c_wheel", false};
	{"f18c_wheel_102", 0, "f18c_wheel", false};
	{"f18c_wheel_103", 0, "f18c_wheel", false};
	{"f18c_wheel_101", 1, "f18c_wheel_nm", false};
	{"f18c_wheel_102", 1, "f18c_wheel_nm", false};
	{"f18c_wheel_103", 1, "f18c_wheel_nm", false};

	{"f18c_glass",	ROUGHNESS_METALLIC ,	"F18C_glass_RoughMet", false};
	{"f18c_glass",	DIFFUSE ,	"F18C_glass", false};
	{"f18c_glass_ils",	DIFFUSE			,	"f18c_glass", false};

	{"cockpit_f18c_2",	DIFFUSE			,	"f18c_cockpit_2_dif", false};
	
}
name = "VMFA-232 100"
countries = {"USA",}

custom_args = 
{
[309] = 1.0,
[310] = 1.0,
[311] = -0.0, --Cheek pad gone 
[312] = 1.0,
[313] = -1.0,
[314] = 1.0,
[315] = 1.0, 
[323] = 0.0, --ladder up
[509] = 0.0, --Helmet Change
[27] = 1, -- Tail      change of type of board number (0.0 -default USA, 0.1- )
[1000] = 1, -- Flaps
[1001] = 1, -- Nose
[1002] = 1, -- Kuwait Squadron 
[1003] = 1, -- Australian Squadron 
[1004] = 1, -- Finland Squadron
[1005] = 1, -- Switzerland Squadron
[1006] = 1, -- Blue Angels Jet Team
}

==> VMFA-323_165208.zip: description.lua <==
livery = {

	{"f18c1", 0 ,"F18C_1_DIFF",false};
	{"f18c1", 1 ,"F18C_1_NM",false};
	{"f18c1", ROUGHNESS_METALLIC ,"F18C_1_DIFF_Roughmet",false};

	
	{"f18c2", 0 ,"F18C_2_DIFF",false};
	{"f18c2", 1 ,"F18C_2_NM",false};
	{"f18c2", ROUGHNESS_METALLIC ,"Hornet_2_RoughMet",false};


	{"FPU_8A", 0 ,"FPU_8A_323",false};
	
	{"pilot_F18_patch", 0 ,"Pilot_F18_Patch",false};
	{"pilot_F18_patch", 1 ,"Pilot_F18_Patch_NORM",false};
	{"pilot_F18_patch", ROUGHNESS_METALLIC ,"Pilot_F18_Patch_RoughMet",false};
	{"pilot_F18_helmet_hmd", 0, "pilot_f18_helmet_hmd",false};
	{"pilot_F18_helmet_hmd", 1, "pilot_f18_helmet_hmd_nm",false};
	{"pilot_F18_helmet_hmd", ROUGHNESS_METALLIC, "pilot_f18_helmet_hmd_roughmet",false};
	{"pilot_F18_helmet", 0, "pilot_f18_helmet",false};
	{"pilot_F18_helmet", 1, "pilot_f18_helmet_nm",false};
	{"pilot_F18_helmet", ROUGHNESS_METALLIC, "pilot_f18_helmet_roughmet",false};
	
	{"Pilot_F18_FP_SuitTop",	DIFFUSE			,	"pilot_f18_fp_suittop", false};
	{"Pilot_F18_FP_SuitBot",	DIFFUSE			,	"pilot_f18_fp_suitbot", false};
	{"Pilot_F18_FP_Details",	DIFFUSE			,	"pilot_f18_fp_details", false};
	{"Pilot_F18_Body",	DIFFUSE			,	"pilot_f18", false};
	{"pilot_F18_visor_glass", 0, "pilot_f18_visor", false};

	
	{"f18c_wheel_101", 0, "f18c_wheel", false};
	{"f18c_wheel_102", 0, "f18c_wheel", false};
	{"f18c_wheel_103", 0, "f18c_wheel", false};
	{"f18c_wheel_101", 1, "f18c_wheel_nm", false};
	{"f18c_wheel_102", 1, "f18c_wheel_nm", false};
	{"f18c_wheel_103", 1, "f18c_wheel_nm", false};

	{"f18c_glass",	ROUGHNESS_METALLIC ,	"F18C_glass_RoughMet", false};
	{"f18c_glass",	DIFFUSE ,	"F18C_glass", false};
	{"f18c_glass_ils",	DIFFUSE			,	"f18c_glass", false};

	{"cockpit_f18c_2",	DIFFUSE			,	"f18c_cockpit_2_dif", false};
	
}
name = "VMFA-323 401 165208"
countries = {"USA",}

custom_args = 
{
[309] = 1.0,
[310] = 1.0,
[311] = -0.0, --Cheek pad gone 
[312] = 1.0,
[313] = -1.0,
[314] = 1.0,
[315] = 1.0, 
[323] = 0.0, --ladder up
[509] = 0.5, --Helmet Change
[27] = 1, -- Tail      change of type of board number (0.0 -default USA, 0.1- )
[1000] = 1, -- Flaps
[1001] = 1, -- Nose
[1002] = 1, -- Kuwait Squadron 
[1003] = 1, -- Australian Squadron 
[1004] = 1, -- Finland Squadron
[1005] = 1, -- Switzerland Squadron
[1006] = 1, -- Blue Angels Jet Team
}
